@@ -182,8 +182,14 @@ public class HibernateDataModel extends DataModel
     private String createHsqlForCount(String hSql)
     {
         String sql = "select count(*) " + hSql.substring(hSql.toLowerCase().indexOf("from"));
-        return sql.replaceAll("order by [^ ]* desc", "").replaceAll("order by [^ ]* asc", "").replaceAll(
-                "order by [^ ]*", "");
+
+        if (log.isDebugEnabled())
+        {
+            log.debug("createHsqlForCount(" + hSql + ")="
+                    + sql.replaceAll("order by(\\s+[^ ]*(\\s+(asc)|(desc))?,?)+", ""));
+        }
+
+        return sql.replaceAll("order by(\\s*[^ ]+(\\s+(asc)|(desc))?,?)+", "");
     }
 
     public void setRowCount(int count)
@@ -341,6 +347,11 @@ public class HibernateDataModel extends DataModel
      */
     private class WrapScrollableResultsMap extends TreeMap
     {
+        /**
+         * 
+         */
+        private static final long serialVersionUID = 2774501371528418953L;
+
         /**
          * Logger for this class
          */
